@@ -264,8 +264,9 @@ class DHCP:
 
         :return Tuple[int, bytearray]: DHCP packet type and ID.
         """
+        global _BUFF  # pylint: disable=global-statement
         # store packet in buffer
-        _BUFF = self._sock.recv()
+        _BUFF = bytearray(self._sock.recv(len(_BUFF)))
         if self._debug:
             print("DHCP Response: ", _BUFF)
 
@@ -401,8 +402,10 @@ class DHCP:
                 self._dhcp_state = _STATE_DHCP_WAIT
             else:
                 self._sock.settimeout(self._response_timeout)
-                self._sock.bind((None, 68))
-                self._sock.connect((self.dhcp_server_ip, _DHCP_SERVER_PORT))
+                self._sock.bind(("", 68))
+                self._sock.connect(
+                    (".".join(map(str, self.dhcp_server_ip)), _DHCP_SERVER_PORT)
+                )
                 if self._last_lease_time == 0 or time.monotonic() > (
                     self._last_lease_time + self._lease_time
                 ):
@@ -421,7 +424,7 @@ class DHCP:
                     self._dhcp_state = _STATE_DHCP_REQUEST
 
         elif self._dhcp_state == _STATE_DHCP_DISCOVER:
-            if self._sock.available():
+            if self._sock._available():  # pylint: disable=protected-access
                 if self._debug:
                     print("* DHCP: Parsing OFFER")
                 try:
@@ -455,7 +458,7 @@ class DHCP:
                             print("* DHCP: Received DHCP Message is not OFFER")
 
         elif self._dhcp_state == _STATE_DHCP_REQUEST:
-            if self._sock.available():
+            if self._sock._available():  # pylint: disable=protected-access
                 if self._debug:
                     print("* DHCP: Parsing ACK")
                 try:
